import { Component, OnInit } from '@angular/core';
import { ViewerService } from 'src/app/services';

@Component({
  selector: 'app-fly-manager',
  templateUrl: './fly-manager.component.html',
  styleUrls: ['./fly-manager.component.css']
})
export class FlyManagerComponent implements OnInit {

  private viewer;
  private flyManager;
  private flyManagerOptions;
  private handler;

  constructor(
    private viewerService: ViewerService,
  ) {
  }

  ngOnInit() {
    this.viewer = this.viewerService.viewer;
    this.flyManagerOptions = {
      perspective: smart3d.FlyPerspective.FIRST,
      duration: 3,
      infinite: false,
      camera: { followX: 100, followZ: 100 }, // FlyPerspective.FIRST
      path: { width: 4, material: new Cesium.PolylineGlowMaterialProperty({ color: Cesium.Color.RED }) },
      point: { pixelSize: 0 },
      model: { uri: 'assets/models/boat.gltf' },
      // label
      // site
    };

    this.flyManager = new smart3d.FlyManager(this.viewer, this.flyManagerOptions);
    this.flyManager.stopArrived.addEventListener(() => {
      this.flyManager.clear();
    });

    this.handler = new smart3d.DrawHandler(this.viewer, smart3d.DrawMode.Line);
    this.handler.drewEvent.addEventListener(cartesians => {
      const updatedCartesians = cartesians.map(cartesian => {
        const cartographic = Cesium.Cartographic.fromCartesian(cartesian);
        return Cesium.Cartesian3.fromRadians(cartographic.longitude, cartographic.latitude, cartographic.height + 1000);
      });
      this.flyManager.addRouteFromPositions(updatedCartesians, this.flyManagerOptions);
      this.handler.clear();
    });
  }

  handleDrawPath(options: {
    clampToGround?: boolean
  }) {
    this.handler.activate();
    // this.flyManager.drawNewRoute({
    //   isGround: undefined !== options.clampToGround ? options.clampToGround : true,
    // });
  }

  startFly() {
    this.flyManager.start();
  }

}
